%TASK: to estimate the chemical enhancement factor (alfa) for given
%temperature and salinity.

%CALCULUS:----------------------------------------------------------------- 

function [Alfa,Scw,Upsw] = estimatealfa(S,Tw,Tkw,NSalfa,NSdw,NSkwind,a,b,c,r,MassFraction,Ms,phiw,Vb)

%--------------------------------------------------------------------------
switch NSalfa
    
    case 'Joh10'
        
        [i_,j_] = size(S);
        ij      =i_*j_;
        S_      = reshape(S,i_*j_,1);
        Tw_     = reshape(Tw,i_*j_,1);
        Tkw_    = reshape(Tkw,i_*j_,1);
        
        MassFraction = cell2mat(MassFraction(2:end,2:end));
        [msi,msj]    = size(MassFraction);
        
        % Mass fraction of pure water                                scalar
        Ww=(1000-S_)./1000;

        % Dynamic viscosity of pure water                          mg/(m.s)
        Etaw0=(Tw_+246)./(0.05594.*Tw_.^2+5.2842.*Tw_+137.37);
        
        % Mass fraction of the solutes                               scalar
        [Ss,Sw] = meshgrid(MassFraction(:,1)',S_);
        Wi      = Ss.*Sw./1000;

        % Dynamic viscosity of solutes                             mg/(m.s)
        Etai = nan(ij,msi);
        V    = nan(ij,msj-1);
        for i=1:msi
            v        = MassFraction(i,2:msj);
            [V,~]    = meshgrid(v,S_);
            Etai(:,i)= exp((V(:,1).*(1-Ww).^V(:,2)+V(:,3))...
                            ./(V(:,4).*Tw_+1))./(V(:,5).*(1-Ww).^V(:,6)+1);
        end

        % Dynamic viscosity of marine water
        Etawg=exp(Ww.*log(Etaw0)+sum(Wi.*log(Etai),2));            %g/(m.s)
        EtawKg=Etawg./1000;                                       %kg/(m.s)

        %Water difusivity scheme ( cm^2/s)
        switch NSdw
            case 'H&L74'
                Dw=13.26*10^-5./(Etawg.^1.4.*Vb^0.598);
                
            case 'H&M82'
                epsilon=9.58/Vb-1.12;
                Dw=1.25*10^-8.*Tkw_.^1.52.*Etawg.^epsilon.*(Vb^-0.19-0.292); 
                
            case 'W&C55'
                Dw=7.4*10^-8.*Tkw_*sqrt(phiw*Ms)./(Etawg.*Vb^0.6);
        end

        % Pure water density                                        %kg/m^3
        Rhow0=r(0+1)+r(1+1).*Tw_+r(2+1).*Tw_.^2+r(3+1).*Tw_.^3 ...
                                            +r(4+1).*Tw_.^4+r(5+1).*Tw_.^5;

        % Parameters a and b to estimate marine water density
        a=a(0+1)+a(1+1).*Tw_+a(2+1).*Tw_.^2+a(3+1).*Tw_.^3+a(4+1).*Tw_.^4; %scalar
        b=b(0+1)+b(1+1).*Tw_+b(2+1).*Tw_.^2;                          %scalar

        % Marine water density                                      %kg/m^3
        Rhow=Rhow0+a.*S_+b.*S_.^(3/2)+c.*S_;
        
        %Kinematic viscosity of water 
        Upsw=EtawKg./Rhow;

        %Schmidt number in water with Upsw converted from m^2/s to cm^2/s
        Scw = Upsw./Dw*10000;                                       %scalar
        Scw = reshape(Scw,i_,j_);

    case 'Bea04'
        Upsw = nan;
        
        %Schmidt number of pure water at given temperature
        Sc0=1800.6-120.1.*Tw+3.7818.*Tw.^2-0.047608.*Tw.^3;
        
        %Schmidt number of water at 35 salinity at given temperature
        Sc35=1953.4-128.*Tw+3.9918.*Tw.^2-0.050091.*Tw.^3;
        
        %Schmidt number of water at given salinity and temperature
        Scw=(Sc35-Sc0).*S./35+Sc0;
           
    case 'Cea96'
        Upsw = nan;
        
        %Schmidt number of water at given temperature
        Scw=2073.1-125.62.*Tw+3.6276.*Tw.^2-0.043219.*Tw.^3;
        
    case 'R&C01'
        Upsw = nan;
        
        %Schmidt number of water at given temperature
        Scw=2073.1-125.62.*Tw+3.6276.*Tw.^2-0.043219.*Tw.^3;
        
end

Alfa=sqrt(600./Scw);

if sum(strcmp(NSkwind,{'Jac99' 'Sea07' 'Wan92' 'W92en' 'Wea07' 'WMG99' 'Zea03' 'ZoJ03' 'ZXi10'}))==1
    Alfa=sqrt(660./Scw);
end

